@@ -374,6 +374,61 @@ def AddConnectionPoolingIgnoreStartupParameters(parser):
   )
 
 
+def AddConnectionPoolingServerLifetime(parser):
+  """Adds --connection-pooling-server-lifetime flag.
+
+  Args:
+    parser: The current argparse parser to add this to.
+  """
+  parser.add_argument(
+      '--connection-pooling-server-lifetime',
+      type=str,
+      required=False,
+      default=None,
+      help=(
+          'The lifetime of a server connection in seconds. The pooler will '
+          'close an unused (not currently linked to any client connection) '
+          'server connection that has been connected longer than this. Setting '
+          ' it to 0 means the connection is to be used only once, then closed. '
+      ),
+  )
+
+
+def AddConnectionPoolingClientConnectionIdleTimeout(parser):
+  """Adds --connection-pooling-client-connection-idle-timeout flag.
+
+  Args:
+    parser: The current argparse parser to add this to.
+  """
+  parser.add_argument(
+      '--connection-pooling-client-connection-idle-timeout',
+      type=str,
+      required=False,
+      default=None,
+      help=(
+          'The maximum number of seconds a client is allowed to be idle '
+          'before it is disconnected.'
+      ),
+  )
+
+
+def AddConnectionPoolingMaxPreparedStatements(parser):
+  """Adds --connection-pooling-max-prepared-statements flag.
+
+  Args:
+    parser: The current argparse parser to add this to.
+  """
+  parser.add_argument(
+      '--connection-pooling-max-prepared-statements',
+      type=arg_parsers.BoundedInt(lower_bound=0),
+      required=False,
+      default=None,
+      help=(
+          'The maximum number of prepared statements allowed.'
+      ),
+  )
+
+
 def AddEnablePrivateServiceConnect(parser):
   """Adds the `--enable-private-service-connect` flag to the parser."""
   parser.add_argument(
@@ -1698,23 +1753,19 @@ def AddRequireConnectors(parser):
   )
 
 
-def AddDatabaseVersion(parser, alloydb_messages, release_track):
+def AddDatabaseVersion(parser, alloydb_messages):
   """Adds Database Version flag.
 
   Args:
     parser: argparse.Parser: Parser object for command line inputs.
     alloydb_messages: Message module.
-    release_track: The command version being used - GA/BETA/ALPHA.
   """
   choices = [
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_14,
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_15,
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_16,
+      alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_17,
   ]
-  if release_track in (base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA):
-    choices.append(
-        alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_17
-    )
   parser.add_argument(
       '--database-version',
       required=False,
@@ -1724,23 +1775,19 @@ def AddDatabaseVersion(parser, alloydb_messages, release_track):
   )
 
 
-def AddVersion(parser, alloydb_messages, release_track):
+def AddVersion(parser, alloydb_messages):
   """Adds Version flag.
 
   Args:
     parser: argparse.Parser: Parser object for command line inputs.
     alloydb_messages: Message module.
-    release_track: The command version being used - GA/BETA/ALPHA.
   """
   choices = [
       alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_14,
       alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_15,
       alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_16,
+      alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_17,
   ]
-  if release_track in (base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA):
-    choices.append(
-        alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_17
-    )
   parser.add_argument(
       '--version',
       required=True,
@@ -1860,6 +1907,37 @@ def AddAuthorizedExternalNetworks(parser):
   )
 
 
+def AddMaintenanceVersion(parser):
+  """Adds a `--maintenance-version` flag to parser.
+
+  Args:
+    parser: argparse.Parser: Parser object for command line inputs.
+  """
+  parser.add_argument(
+      '--maintenance-version',
+      required=False,
+      type=str,
+      hidden=True,
+      help=(
+          'Maintenance version to update the cluster to. Use `latest` to'
+          ' apply the latest available maintenance version.'
+      ),
+  )
+
+
+def GetValidatedMaintenanceVersion(args, alloydb_messages):
+  """Returns the maintenance version from the args."""
+  if args.maintenance_version.lower() == 'latest':
+    return (
+        alloydb_messages.Cluster.MaintenanceVersionSelectionPolicyValueValuesEnum.MAINTENANCE_VERSION_SELECTION_POLICY_LATEST
+    )
+  raise exceptions.InvalidArgumentException(
+      '--maintenance-version',
+      'Invalid maintenance version: {}. Use `latest` to apply the latest'
+      ' available maintenance version.'.format(args.maintenance_version)
+  )
+
+
 def _AddMaintenanceWindowAny(group):
   """Adds maintenance window any flag to the group."""
   group.add_argument(
