@@ -181,6 +181,7 @@ def _ConstructInstanceFromArgs(client, alloydb_messages, args):
       assign_inbound_public_ip=args.assign_inbound_public_ip,
       authorized_external_networks=args.authorized_external_networks,
       outbound_public_ip=args.outbound_public_ip,
+      allocated_ip_range_override=args.allocated_ip_range_override,
   )
 
   if (
@@ -251,6 +252,10 @@ def _ConstructInstanceFromArgsAlpha(client, alloydb_messages, args):
         connection_pooling_query_wait_timeout=args.connection_pooling_query_wait_timeout,
         connection_pooling_stats_users=args.connection_pooling_stats_users,
         connection_pooling_ignore_startup_parameters=args.connection_pooling_ignore_startup_parameters,
+        connection_pooling_server_lifetime=args.connection_pooling_server_lifetime,
+        connection_pooling_client_connection_idle_timeout=args.connection_pooling_client_connection_idle_timeout,
+        connection_pooling_max_prepared_statements=args.connection_pooling_max_prepared_statements,
+        args=args,
     )
 
   return instance_resource
@@ -287,6 +292,7 @@ def _ConstructSecondaryInstanceFromArgs(client, alloydb_messages, args):
       assign_inbound_public_ip=args.assign_inbound_public_ip,
       authorized_external_networks=args.authorized_external_networks,
       outbound_public_ip=args.outbound_public_ip,
+      allocated_ip_range_override=args.allocated_ip_range_override,
   )
   if (
       args.allowed_psc_projects
@@ -302,6 +308,62 @@ def _ConstructSecondaryInstanceFromArgs(client, alloydb_messages, args):
   return instance_resource
 
 
+def _ConstructSecondaryInstanceFromArgsBeta(client, alloydb_messages, args):
+  """Validates command line input arguments and passes parent's resources to create an AlloyDB secondary instance for beta track.
+
+  Args:
+    client: Client for api_utils.py class.
+    alloydb_messages: Messages module for the API client.
+    args: Command line input arguments.
+
+  Returns:
+    An AlloyDB secondary instance to create with the specified command line
+    arguments.
+  """
+
+  return _ConstructSecondaryInstanceFromArgs(
+      client, alloydb_messages, args
+  )
+
+
+def _ConstructSecondaryInstanceFromArgsAlpha(client, alloydb_messages, args):
+  """Validates command line input arguments and passes parent's resources to create an AlloyDB secondary instance for alpha track.
+
+  Args:
+    client: Client for api_utils.py class.
+    alloydb_messages: Messages module for the API client.
+    args: Command line input arguments.
+
+  Returns:
+    An AlloyDB secondary instance to create with the specified command line
+    arguments.
+  """
+
+  instance_resource = _ConstructSecondaryInstanceFromArgsBeta(
+      client, alloydb_messages, args
+  )
+
+  if args.enable_connection_pooling:
+    instance_resource.connectionPoolConfig = _ConnectionPoolConfig(
+        alloydb_messages=alloydb_messages,
+        enable_connection_pooling=args.enable_connection_pooling,
+        connection_pooling_pool_mode=args.connection_pooling_pool_mode,
+        connection_pooling_min_pool_size=args.connection_pooling_min_pool_size,
+        connection_pooling_max_pool_size=args.connection_pooling_max_pool_size,
+        connection_pooling_max_client_conn=args.connection_pooling_max_client_connections,
+        connection_pooling_server_idle_timeout=args.connection_pooling_server_idle_timeout,
+        connection_pooling_query_wait_timeout=args.connection_pooling_query_wait_timeout,
+        connection_pooling_stats_users=args.connection_pooling_stats_users,
+        connection_pooling_ignore_startup_parameters=args.connection_pooling_ignore_startup_parameters,
+        connection_pooling_server_lifetime=args.connection_pooling_server_lifetime,
+        connection_pooling_client_connection_idle_timeout=args.connection_pooling_client_connection_idle_timeout,
+        connection_pooling_max_prepared_statements=args.connection_pooling_max_prepared_statements,
+        args=args,
+    )
+
+  return instance_resource
+
+
 def ConstructSecondaryCreateRequestFromArgsGA(
     client, alloydb_messages, cluster_ref, args
 ):
@@ -318,11 +380,25 @@ def ConstructSecondaryCreateRequestFromArgsGA(
   )
 
 
-def ConstructSecondaryCreateRequestFromArgsAlphaBeta(
+def ConstructSecondaryCreateRequestFromArgsBeta(
     client, alloydb_messages, cluster_ref, args
 ):
-  """Validates command line input arguments and passes parent's resources for alpha/beta track."""
-  instance_resource = _ConstructSecondaryInstanceFromArgs(
+  """Validates command line input arguments and passes parent's resources for beta track."""
+  instance_resource = _ConstructSecondaryInstanceFromArgsBeta(
+      client, alloydb_messages, args
+  )
+  return alloydb_messages.AlloydbProjectsLocationsClustersInstancesCreatesecondaryRequest(
+      instance=instance_resource,
+      instanceId=args.instance,
+      parent=cluster_ref.RelativeName(),
+  )
+
+
+def ConstructSecondaryCreateRequestFromArgsAlpha(
+    client, alloydb_messages, cluster_ref, args
+):
+  """Validates command line input arguments and passes parent's resources for alpha track."""
+  instance_resource = _ConstructSecondaryInstanceFromArgsAlpha(
       client, alloydb_messages, args
   )
   return alloydb_messages.AlloydbProjectsLocationsClustersInstancesCreatesecondaryRequest(
@@ -725,11 +801,13 @@ def NetworkConfig(**kwargs):
   authorized_external_networks = kwargs.get('authorized_external_networks')
   alloydb_messages = kwargs.get('alloydb_messages')
   outbound_public_ip = kwargs.get('outbound_public_ip')
+  allocated_ip_range_override = kwargs.get('allocated_ip_range_override')
 
   should_generate_config = any([
       assign_inbound_public_ip,
       outbound_public_ip is not None,
       authorized_external_networks is not None,
+      allocated_ip_range_override is not None,
   ])
   if not should_generate_config:
     return None
@@ -762,6 +840,11 @@ def NetworkConfig(**kwargs):
             instance_network_config.enablePublicIp,
         )
     )
+
+  if allocated_ip_range_override is not None:
+    instance_network_config.allocatedIpRangeOverride = (
+        allocated_ip_range_override
+    )
   return instance_network_config
 
 
@@ -781,27 +864,54 @@ def _ConnectionPoolConfig(**kwargs):
   ignore_startup_parameters = kwargs.get(
       'connection_pooling_ignore_startup_parameters'
   )
+  server_lifetime = kwargs.get(
+      'connection_pooling_server_lifetime'
+  )
+  client_connection_idle_timeout = kwargs.get(
+      'connection_pooling_client_connection_idle_timeout'
+  )
+  max_prepared_statements = kwargs.get(
+      'connection_pooling_max_prepared_statements'
+  )
 
   alloydb_messages = kwargs.get('alloydb_messages')
   config = alloydb_messages.ConnectionPoolConfig()
   config.enable = enable_connection_pooling
   config.enabled = enable_connection_pooling
+  flags = {}
   if pool_mode is not None:
-    config.poolMode = _ParsePoolMode(alloydb_messages, pool_mode)
+    flags['pool_mode'] = pool_mode.lower()
   if min_pool_size is not None:
-    config.minPoolSize = min_pool_size
+    flags['min_pool_size'] = min_pool_size
   if default_pool_size is not None:
-    config.defaultPoolSize = default_pool_size
+    flags['max_pool_size'] = default_pool_size
   if max_client_conn is not None:
-    config.maxClientConn = max_client_conn
+    flags['max_client_connections'] = max_client_conn
   if server_idle_timeout is not None:
-    config.serverIdleTimeout = server_idle_timeout
+    flags['server_connection_idle_timeout'] = server_idle_timeout
   if query_wait_timeout is not None:
-    config.queryWaitTimeout = query_wait_timeout
+    flags['query_wait_timeout'] = query_wait_timeout
   if stats_users is not None:
-    config.statsUsers = stats_users
+    flags['stats_users'] = ','.join(stats_users)
   if ignore_startup_parameters is not None:
-    config.ignoreStartupParameters = ignore_startup_parameters
+    flags['ignore_startup_parameters'] = ','.join(ignore_startup_parameters)
+  if server_lifetime is not None:
+    flags['server_lifetime'] = server_lifetime
+  if client_connection_idle_timeout is not None:
+    flags['client_connection_idle_timeout'] = (
+        client_connection_idle_timeout
+    )
+  if max_prepared_statements is not None:
+    flags['max_prepared_statements'] = str(max_prepared_statements)
+
+  config.flags = alloydb_messages.ConnectionPoolConfig.FlagsValue(
+      additionalProperties=[
+          alloydb_messages.ConnectionPoolConfig.FlagsValue.AdditionalProperty(
+              key=key, value=value
+          )
+          for key, value in flags.items()
+      ]
+  )
   return config
 
 
@@ -827,6 +937,15 @@ def _UpdateConnectionPoolConfig(instance_ref, **kwargs):
   ignore_startup_parameters = kwargs.get(
       'connection_pooling_ignore_startup_parameters'
   )
+  server_lifetime = kwargs.get(
+      'connection_pooling_server_lifetime'
+  )
+  client_connection_idle_timeout = kwargs.get(
+      'connection_pooling_client_connection_idle_timeout'
+  )
+  max_prepared_statements = kwargs.get(
+      'connection_pooling_max_prepared_statements'
+  )
   alloydb_messages = kwargs.get('alloydb_messages')
 
   should_update_config = any([
@@ -839,11 +958,15 @@ def _UpdateConnectionPoolConfig(instance_ref, **kwargs):
       query_wait_timeout is not None,
       stats_users is not None,
       ignore_startup_parameters is not None,
+      server_lifetime is not None,
+      client_connection_idle_timeout is not None,
+      max_prepared_statements is not None,
   ])
   if not should_update_config:
     return None
 
   config = alloydb_messages.ConnectionPoolConfig()
+  flags = {}
 
   # Disabling managed connection pooling should set all other connection pooling
   # settings to None.
@@ -853,66 +976,101 @@ def _UpdateConnectionPoolConfig(instance_ref, **kwargs):
     return config
 
   # Build the connection pooling config based on the existing values that are
-  # set in the instance, if they aren't specified in the update.
+  # set in the instance, if they aren't specified in the update. If the flag
+  # is set in the update, it will override the existing value.
   client = api_util.AlloyDBClient(base.ReleaseTrack.ALPHA)
   alloydb_client = client.alloydb_client
   req = alloydb_messages.AlloydbProjectsLocationsClustersInstancesGetRequest(
       name=instance_ref.RelativeName()
   )
-  existing_instance = (
-      alloydb_client.projects_locations_clusters_instances.Get(req)
+  existing_instance = alloydb_client.projects_locations_clusters_instances.Get(
+      req
   )
+  has_existing_config = existing_instance.connectionPoolConfig is not None
+  if (
+      has_existing_config
+      and existing_instance.connectionPoolConfig.flags is not None
+  ):
+    flag_names = [
+        'pool_mode',
+        'min_pool_size',
+        'max_pool_size',
+        'max_client_connections',
+        'server_connection_idle_timeout',
+        'query_wait_timeout',
+        'stats_users',
+        'ignore_startup_parameters',
+        'server_lifetime',
+        'client_connection_idle_timeout',
+        'max_prepared_statements'
+    ]
+    for f in flag_names:
+      exists, value = _CheckIfConnectionPoolConfigFlagExists(
+          existing_instance, f
+      )
+      if exists:
+        flags[f] = value
 
   if enable_connection_pooling is not None:
     config.enable = enable_connection_pooling
     config.enabled = enable_connection_pooling
-  else:
+  elif has_existing_config:
     config.enable = existing_instance.connectionPoolConfig.enable
     config.enabled = existing_instance.connectionPoolConfig.enabled
 
   if pool_mode is not None:
-    config.poolMode = _ParsePoolMode(alloydb_messages, pool_mode)
-  else:
-    config.poolMode = existing_instance.connectionPoolConfig.poolMode
+    flags['pool_mode'] = pool_mode.lower()
   if min_pool_size is not None:
-    config.minPoolSize = min_pool_size
-  else:
-    config.minPoolSize = existing_instance.connectionPoolConfig.minPoolSize
+    flags['min_pool_size'] = min_pool_size
   if default_pool_size is not None:
-    config.defaultPoolSize = default_pool_size
-  else:
-    config.defaultPoolSize = (
-        existing_instance.connectionPoolConfig.defaultPoolSize
-    )
+    flags['max_pool_size'] = default_pool_size
   if max_client_conn is not None:
-    config.maxClientConn = max_client_conn
-  else:
-    config.maxClientConn = existing_instance.connectionPoolConfig.maxClientConn
+    flags['max_client_connections'] = max_client_conn
   if server_idle_timeout is not None:
-    config.serverIdleTimeout = server_idle_timeout
-  else:
-    config.serverIdleTimeout = (
-        existing_instance.connectionPoolConfig.serverIdleTimeout
-    )
+    flags['server_connection_idle_timeout'] = server_idle_timeout
   if query_wait_timeout is not None:
-    config.queryWaitTimeout = query_wait_timeout
-  else:
-    config.queryWaitTimeout = (
-        existing_instance.connectionPoolConfig.queryWaitTimeout
-    )
+    flags['query_wait_timeout'] = query_wait_timeout
   if stats_users is not None:
-    config.statsUsers = stats_users
-  else:
-    config.statsUsers = existing_instance.connectionPoolConfig.statsUsers
+    flags['stats_users'] = ','.join(stats_users)
   if ignore_startup_parameters is not None:
-    config.ignoreStartupParameters = ignore_startup_parameters
-  else:
-    config.ignoreStartupParameters = (
-        existing_instance.connectionPoolConfig.ignoreStartupParameters
-    )
+    flags['ignore_startup_parameters'] = ','.join(ignore_startup_parameters)
+  if server_lifetime is not None:
+    flags['server_lifetime'] = server_lifetime
+  if client_connection_idle_timeout is not None:
+    flags['client_connection_idle_timeout'] = client_connection_idle_timeout
+  if max_prepared_statements is not None:
+    flags['max_prepared_statements'] = str(max_prepared_statements)
+
+  config.flags = alloydb_messages.ConnectionPoolConfig.FlagsValue(
+      additionalProperties=[
+          alloydb_messages.ConnectionPoolConfig.FlagsValue.AdditionalProperty(
+              key=key, value=value
+          )
+          for key, value in flags.items()
+      ]
+  )
   return config
 
 
+def _CheckIfConnectionPoolConfigFlagExists(instance, flag_name):
+  """Checks if a flag exists in the instance's connection pool config.
+
+  Args:
+    instance: The existing instance to check against.
+    flag_name: The name of the flag to check if it exists in the instance.
+
+  Returns:
+    True and the value of the flag if the flag exists, False otherwise.
+
+  """
+  if instance.connectionPoolConfig.flags.additionalProperties is None:
+    return False, None
+  for prop in instance.connectionPoolConfig.flags.additionalProperties:
+    if prop.key == flag_name:
+      return True, prop.value
+  return False, None
+
+
 def PscInstanceConfig(**kwargs):
   """Generates the PSC instance config for the instance."""
   alloydb_messages = kwargs.get('alloydb_messages')
@@ -1150,22 +1308,28 @@ def ConstructInstanceAndUpdatePathsFromArgsAlpha(
       or args.connection_pooling_server_idle_timeout is not None
       or args.connection_pooling_query_wait_timeout is not None
       or args.connection_pooling_stats_users is not None
-      or args.connection_pooling_ignore_startup_parameters is not None):
+      or args.connection_pooling_ignore_startup_parameters is not None
+      or args.connection_pooling_server_lifetime is not None
+      or args.connection_pooling_client_connection_idle_timeout is not None
+      or args.connection_pooling_max_prepared_statements is not None):
     paths.append('connectionPoolConfig')
 
-  instance_resource.connectionPoolConfig = _UpdateConnectionPoolConfig(
-      instance_ref,
-      alloydb_messages=alloydb_messages,
-      enable_connection_pooling=args.enable_connection_pooling,
-      connection_pooling_pool_mode=args.connection_pooling_pool_mode,
-      connection_pooling_min_pool_size=args.connection_pooling_min_pool_size,
-      connection_pooling_max_pool_size=args.connection_pooling_max_pool_size,
-      connection_pooling_max_client_conn=args.connection_pooling_max_client_connections,
-      connection_pooling_server_idle_timeout=args.connection_pooling_server_idle_timeout,
-      connection_pooling_query_wait_timeout=args.connection_pooling_query_wait_timeout,
-      connection_pooling_stats_users=args.connection_pooling_stats_users,
-      connection_pooling_ignore_startup_parameters=args.connection_pooling_ignore_startup_parameters,
-  )
+    instance_resource.connectionPoolConfig = _UpdateConnectionPoolConfig(
+        instance_ref,
+        alloydb_messages=alloydb_messages,
+        enable_connection_pooling=args.enable_connection_pooling,
+        connection_pooling_pool_mode=args.connection_pooling_pool_mode,
+        connection_pooling_min_pool_size=args.connection_pooling_min_pool_size,
+        connection_pooling_max_pool_size=args.connection_pooling_max_pool_size,
+        connection_pooling_max_client_conn=args.connection_pooling_max_client_connections,
+        connection_pooling_server_idle_timeout=args.connection_pooling_server_idle_timeout,
+        connection_pooling_query_wait_timeout=args.connection_pooling_query_wait_timeout,
+        connection_pooling_stats_users=args.connection_pooling_stats_users,
+        connection_pooling_ignore_startup_parameters=args.connection_pooling_ignore_startup_parameters,
+        connection_pooling_server_lifetime=args.connection_pooling_server_lifetime,
+        connection_pooling_client_connection_idle_timeout=args.connection_pooling_client_connection_idle_timeout,
+        connection_pooling_max_prepared_statements=args.connection_pooling_max_prepared_statements,
+    )
   return instance_resource, paths
 
 
