@@ -86,6 +86,7 @@ class Create(base.CreateCommand):
     flags.AddAllowedPSCProjects(parser)
     flags.AddPSCNetworkAttachmentUri(parser)
     flags.AddPSCAutoConnections(parser)
+    flags.AddAllocatedIPRangeOverride(parser)
     # TODO(b/185795425): Add --ssl-required and --labels later once we
     # understand the use cases
 
@@ -178,6 +179,9 @@ class CreateAlpha(CreateBeta):
     flags.AddConnectionPoolingQueryWaitTimeout(parser)
     flags.AddConnectionPoolingStatsUsers(parser)
     flags.AddConnectionPoolingIgnoreStartupParameters(parser)
+    flags.AddConnectionPoolingServerLifetime(parser)
+    flags.AddConnectionPoolingClientConnectionIdleTimeout(parser)
+    flags.AddConnectionPoolingMaxPreparedStatements(parser)
 
   def ConstructCreateRequestFromArgs(
       self, client, alloydb_messages, cluster_ref, args
