@@ -507,6 +507,11 @@ def ParseCreateOptionsBase(
       secret_manager_rotation_interval=get_default(
           'secret_manager_rotation_interval'
       ),
+      enable_secret_sync=get_default('enable_secret_sync'),
+      enable_secret_sync_rotation=get_default('enable_secret_sync_rotation'),
+      secret_sync_rotation_interval=get_default(
+          'secret_sync_rotation_interval'
+      ),
       enable_cilium_clusterwide_network_policy=get_default(
           'enable_cilium_clusterwide_network_policy'
       ),
@@ -558,7 +563,6 @@ def ParseCreateOptionsBase(
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
-
       boot_disk_provisioned_iops=get_default('boot_disk_provisioned_iops'),
       boot_disk_provisioned_throughput=get_default(
           'boot_disk_provisioned_throughput'
@@ -636,6 +640,10 @@ def AttrValue(args, flagname, flag_defaults):
   return getattr(args, flagname, DefaultAttribute(flagname, flag_defaults))
 
 
+# Flags for "clusters create" should also be added to "clusters create-auto"
+# Unless there is a good reason to exclude them because features should support
+# both GKE Standard and Autopilot.
+# LINT.IfChange(flags_to_add)
 flags_to_add = {
     GA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, False, True),
@@ -775,9 +783,7 @@ flags_to_add = {
             flags.AddRuntimeVulnerabilityInsightFlag
         ),
         'containerdConfig': flags.AddContainerdConfigFlag,
-        'secretManagerConfig': lambda p: flags.AddSecretManagerEnableFlagGroup(
-            p, hidden=True
-        ),
+        'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
@@ -981,6 +987,7 @@ flags_to_add = {
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'containerdConfig': flags.AddContainerdConfigFlag,
         'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
+        'secretSyncConfig': flags.AddSecretSyncFlagGroup,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
         ),
@@ -1187,6 +1194,7 @@ flags_to_add = {
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'containerdConfig': flags.AddContainerdConfigFlag,
         'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
+        'secretSyncConfig': flags.AddSecretSyncFlagGroup,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
         ),
@@ -1219,6 +1227,7 @@ flags_to_add = {
         'networkTier': flags.AddNetworkTierFlag,
     },
 }
+# LINT.ThenChange(create_auto.py:auto_flags)
 
 
 def AddFlags(channel, parser, flag_defaults, allowlist=None):
