@@ -421,11 +421,9 @@ class Update(base.UpdateCommand):
     flags.AddAutoprovisioningEnableKubeletReadonlyPortFlag(group)
     flags.AddEnableRayClusterLogging(group, is_update=True)
     flags.AddEnableRayClusterMonitoring(group, is_update=True)
-    flags.AddSecretManagerEnableFlagGroup(
-        group, release_track=base.ReleaseTrack.GA
-    )
+    flags.AddSecretManagerEnableFlagGroup(group, is_update=True)
     flags.AddInsecureRBACBindingFlags(group, hidden=False)
-    group_add_additional_ip_ranges = group.add_group(hidden=True)
+    group_add_additional_ip_ranges = group.add_group()
     flags.AddAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddRemoveAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddClusterEnablePrivateNodesFlag(group)
@@ -449,10 +447,12 @@ class Update(base.UpdateCommand):
     flags.AddEnableK8sCertsViaDnsFlag(group_for_control_plane_endpoints)
     flags.AddServiceAccountVerificationKeysFlag(group)
     flags.AddServiceAccountSigningKeysFlag(group)
+    flags.AddControlPlaneDiskEncryptionKeyFlag(group)
     flags.AddPatchUpdateFlag(group)
-    flags.AddAutoIpamFlag(group, hidden=True, is_update=True)
-    flags.AddEnableLegacyLustrePortFlag(group, hidden=True)
+    flags.AddAutoIpamFlag(group, is_update=True)
+    flags.AddEnableLegacyLustrePortFlag(group, hidden=False)
     flags.AddEnableDefaultComputeClassFlag(group)
+    flags.AddNetworkTierFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -568,6 +568,10 @@ class Update(base.UpdateCommand):
     opts.enable_ray_cluster_logging = args.enable_ray_cluster_logging
     opts.enable_ray_cluster_monitoring = args.enable_ray_cluster_monitoring
     opts.enable_secret_manager = args.enable_secret_manager
+    opts.enable_secret_manager_rotation = args.enable_secret_manager_rotation
+    opts.secret_manager_rotation_interval = (
+        args.secret_manager_rotation_interval
+    )
     opts.enable_insecure_binding_system_authenticated = (
         args.enable_insecure_binding_system_authenticated
     )
@@ -594,6 +598,9 @@ class Update(base.UpdateCommand):
         args.service_account_verification_keys
     )
     opts.service_account_signing_keys = args.service_account_signing_keys
+    opts.control_plane_disk_encryption_key = (
+        args.control_plane_disk_encryption_key
+    )
     opts.anonymous_authentication_config = args.anonymous_authentication_config
     opts.patch_update = args.patch_update
     opts.enable_auto_ipam = args.enable_auto_ipam
@@ -602,6 +609,7 @@ class Update(base.UpdateCommand):
     opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
     opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
     opts.enable_default_compute_class = args.enable_default_compute_class
+    opts.network_tier = args.network_tier
     return opts
 
   def Run(self, args):
@@ -1169,7 +1177,6 @@ class UpdateBeta(Update):
     flags.AddAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
     flags.AddRemoveAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
     flags.AddGatewayFlags(group, hidden=False)
-    flags.AddFleetProjectFlag(group, is_update=True)
     flags.AddComplianceFlags(group, hidden=True)
     flags.AddSecurityPostureFlag(group)
     flags.AddClusterNetworkPerformanceConfigFlags(group)
@@ -1190,16 +1197,15 @@ class UpdateBeta(Update):
     flags.AddConvertToAutopilotFlag(group)
     flags.AddCompleteConvertToAutopilotFlag(group)
     flags.AddConvertToStandardFlag(group)
-    flags.AddSecretManagerEnableFlagGroup(
-        group, release_track=base.ReleaseTrack.BETA
-    )
+    flags.AddSecretManagerEnableFlagGroup(group, is_update=True)
+    flags.AddSecretSyncFlagGroup(group, hidden=True, is_update=True)
     flags.AddEnableCiliumClusterwideNetworkPolicyFlag(group, is_update=True)
     flags.AddEnableKubeletReadonlyPortFlag(group)
     flags.AddAutoprovisioningEnableKubeletReadonlyPortFlag(group)
     flags.AddEnableRayClusterLogging(group, is_update=True)
     flags.AddEnableRayClusterMonitoring(group, is_update=True)
     flags.AddInsecureRBACBindingFlags(group, hidden=False)
-    group_add_additional_ip_ranges = group.add_group(hidden=True)
+    group_add_additional_ip_ranges = group.add_group()
     flags.AddAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddRemoveAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddClusterEnablePrivateNodesFlag(group)
@@ -1223,10 +1229,15 @@ class UpdateBeta(Update):
     flags.AddEnableK8sCertsViaDnsFlag(group_for_control_plane_endpoints)
     flags.AddServiceAccountVerificationKeysFlag(group)
     flags.AddServiceAccountSigningKeysFlag(group)
+    flags.AddControlPlaneDiskEncryptionKeyFlag(group)
     flags.AddPatchUpdateFlag(group)
-    flags.AddAutoIpamFlag(group, hidden=True, is_update=True)
-    flags.AddEnableLegacyLustrePortFlag(group, hidden=True)
+    flags.AddAutoIpamFlag(group, is_update=True)
+    flags.AddEnableLegacyLustrePortFlag(group, hidden=False)
     flags.AddEnableDefaultComputeClassFlag(group)
+    group_fleet_flags = group.add_group()
+    flags.AddFleetProjectFlag(group_fleet_flags, is_update=True)
+    flags.AddMembershipTypeFlags(group_fleet_flags, is_update=True)
+    flags.AddNetworkTierFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1357,6 +1368,8 @@ class UpdateBeta(Update):
     opts.gateway_api = args.gateway_api
     opts.fleet_project = args.fleet_project
     opts.enable_fleet = args.enable_fleet
+    opts.membership_type = args.membership_type
+    opts.unset_membership_type = args.unset_membership_type
     opts.clear_fleet_project = args.clear_fleet_project
     opts.enable_security_posture = args.enable_security_posture
     opts.network_performance_config = args.network_performance_configs
@@ -1382,6 +1395,9 @@ class UpdateBeta(Update):
     opts.secret_manager_rotation_interval = (
         args.secret_manager_rotation_interval
     )
+    opts.enable_secret_sync = args.enable_secret_sync
+    opts.enable_secret_sync_rotation = args.enable_secret_sync_rotation
+    opts.secret_sync_rotation_interval = args.secret_sync_rotation_interval
     opts.enable_cilium_clusterwide_network_policy = (
         args.enable_cilium_clusterwide_network_policy
     )
@@ -1419,6 +1435,9 @@ class UpdateBeta(Update):
         args.service_account_verification_keys
     )
     opts.service_account_signing_keys = args.service_account_signing_keys
+    opts.control_plane_disk_encryption_key = (
+        args.control_plane_disk_encryption_key
+    )
     opts.anonymous_authentication_config = args.anonymous_authentication_config
     opts.patch_update = args.patch_update
     opts.enable_auto_ipam = args.enable_auto_ipam
@@ -1427,6 +1446,7 @@ class UpdateBeta(Update):
     opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
     opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
     opts.enable_default_compute_class = args.enable_default_compute_class
+    opts.network_tier = args.network_tier
     return opts
 
 
@@ -1517,7 +1537,6 @@ class UpdateAlpha(Update):
     group_add_pod_ipv4_ranges = group.add_group(hidden=False)
     flags.AddAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
     flags.AddRemoveAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
-    flags.AddFleetProjectFlag(group, is_update=True)
     flags.AddComplianceFlags(group, hidden=True)
     flags.AddSecurityPostureFlag(group)
     flags.AddClusterNetworkPerformanceConfigFlags(group)
@@ -1538,16 +1557,15 @@ class UpdateAlpha(Update):
     flags.AddConvertToAutopilotFlag(group)
     flags.AddCompleteConvertToAutopilotFlag(group)
     flags.AddConvertToStandardFlag(group)
-    flags.AddSecretManagerEnableFlagGroup(
-        group, release_track=base.ReleaseTrack.ALPHA
-    )
+    flags.AddSecretManagerEnableFlagGroup(group, is_update=True)
+    flags.AddSecretSyncFlagGroup(group, hidden=True, is_update=True)
     flags.AddEnableCiliumClusterwideNetworkPolicyFlag(group, is_update=True)
     flags.AddEnableKubeletReadonlyPortFlag(group)
     flags.AddAutoprovisioningEnableKubeletReadonlyPortFlag(group)
     flags.AddEnableRayClusterLogging(group, is_update=True)
     flags.AddEnableRayClusterMonitoring(group, is_update=True)
     flags.AddInsecureRBACBindingFlags(group, hidden=False)
-    group_add_additional_ip_ranges = group.add_group(hidden=True)
+    group_add_additional_ip_ranges = group.add_group()
     flags.AddAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddRemoveAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddClusterEnablePrivateNodesFlag(group)
@@ -1571,10 +1589,15 @@ class UpdateAlpha(Update):
     flags.AddEnableK8sCertsViaDnsFlag(group_for_control_plane_endpoints)
     flags.AddServiceAccountVerificationKeysFlag(group)
     flags.AddServiceAccountSigningKeysFlag(group)
+    flags.AddControlPlaneDiskEncryptionKeyFlag(group)
     flags.AddPatchUpdateFlag(group)
-    flags.AddAutoIpamFlag(group, hidden=True, is_update=True)
-    flags.AddEnableLegacyLustrePortFlag(group, hidden=True)
+    flags.AddAutoIpamFlag(group, is_update=True)
+    flags.AddEnableLegacyLustrePortFlag(group, hidden=False)
     flags.AddEnableDefaultComputeClassFlag(group)
+    group_fleet_flags = group.add_group()
+    flags.AddFleetProjectFlag(group_fleet_flags, is_update=True)
+    flags.AddMembershipTypeFlags(group_fleet_flags, is_update=True)
+    flags.AddNetworkTierFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1701,6 +1724,8 @@ class UpdateAlpha(Update):
     opts.remove_additional_ip_ranges = args.remove_additional_ip_ranges
     opts.fleet_project = args.fleet_project
     opts.enable_fleet = args.enable_fleet
+    opts.membership_type = args.membership_type
+    opts.unset_membership_type = args.unset_membership_type
     opts.clear_fleet_project = args.clear_fleet_project
     opts.enable_security_posture = args.enable_security_posture
     opts.network_performance_config = args.network_performance_configs
@@ -1726,6 +1751,9 @@ class UpdateAlpha(Update):
     opts.secret_manager_rotation_interval = (
         args.secret_manager_rotation_interval
     )
+    opts.enable_secret_sync = args.enable_secret_sync
+    opts.enable_secret_sync_rotation = args.enable_secret_sync_rotation
+    opts.secret_sync_rotation_interval = args.secret_sync_rotation_interval
     opts.enable_cilium_clusterwide_network_policy = (
         args.enable_cilium_clusterwide_network_policy
     )
@@ -1763,6 +1791,9 @@ class UpdateAlpha(Update):
         args.service_account_verification_keys
     )
     opts.service_account_signing_keys = args.service_account_signing_keys
+    opts.control_plane_disk_encryption_key = (
+        args.control_plane_disk_encryption_key
+    )
     opts.anonymous_authentication_config = args.anonymous_authentication_config
     opts.patch_update = args.patch_update
     opts.enable_auto_ipam = args.enable_auto_ipam
@@ -1771,4 +1802,5 @@ class UpdateAlpha(Update):
     opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
     opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
     opts.enable_default_compute_class = args.enable_default_compute_class
+    opts.network_tier = args.network_tier
     return opts
